@@ -1,8 +1,8 @@
-# $Id: filehandles.pm 1813 2005-06-28 06:18:21Z rcaputo $
+# $Id: filehandles.pm 1971 2006-05-30 20:32:30Z bsmith $
 
 use strict;
 
-use lib qw(./mylib ./lib);
+use lib qw(./mylib ../mylib);
 
 sub POE::Kernel::ASSERT_DEFAULT () { 1 }
 sub POE::Kernel::TRACE_DEFAULT  () { 1 }
